==> appfs-21.02.tar.gz: usr/local/www/berogui/misc/script/sip.js <==
function hide_reg(value, state) {
    typeof state == 'undefined' ? state = true : state;
    if (value == false) {
        $('#reg').hide();
        $('#reg_option').hide();
    } else if (state === true) {
        $('#reg').show();
        $('#reg_option').show();
    }
}

function hide_validation(value, state) {
    typeof state == 'undefined' ? state = true : state;
    if (value == false) {
        $('#keepalive_int').hide();
        $('#regrefresh_on_validation_fail').hide();
    } else if (state === true) {
        $('#keepalive_int').show();
        $('#regrefresh_on_validation_fail').show();
    }
}


function disable_ipMatchtype() {
    if ($('#manual').prop('checked') == true) {
        $('#address').prop('disabled', true);
        $('#address').prop('checked', false);
    }
    if ($('#manual').prop('checked') == false) {
        $('#address').prop('disabled', false);
    }
}

function hide_server(value) {
    if (value === false) {
        $('.sip_proxy').show();
        $('#sip_proxy').prop('disabled', false);
        $('.enum_search_domains').hide();
        $('#enum_search_domains').prop('disabled', true);
    } else if (value === true) {
        $('.sip_proxy').hide();
        $('#sip_proxy').prop('disabled', true);
        $('.enum_search_domains').show();
        $('#enum_search_domains').prop('disabled', false);
    }
}

function options(stun, externip, state) {
    typeof state == 'undefined' ? state = true : state;
    if ((stun == false && externip == false) || state == false) {
        $(".options").hide();
    } else if (state == true) {
        $(".options").show();
    }
    if (stun == true && state == true) {
        $(".stun").show();
        $(".externip").hide();
    } else {
        $(".stun").hide();
    }
    if (externip == true && state == true) {
        $(".externip").show();
        $(".stun").hide();
    } else {
        $(".externip").hide();
    }
}

function srtp() {
    if ($("#srtp_mode").val() == "off") {
        $("#srtp_crypto_suites").prop("disabled", true);
        $(".srtp_crypto_suites").hide();
        required();
    } else {
        $(".srtp_crypto_suites").show();
        $("#srtp_crypto_suites").prop("disabled", false);
        required();
    }
}
$("#stunradio").click(function () {
    $(".options").show();
    $(".stun").show();
    $(".externip").hide();
});
$("#externipradio").click(function () {
    $(".options").show();
    $(".externip").show();
    $(".stun").hide();
});
$("#nonatradio").click(function () {
    $(".options").hide();
    $(".externip").hide();
    $(".stun").hide();
});
$("#manual").click(function () {
    disable_ipMatchtype();
});


function move(Orig, Dest) {
    var varFromBox = document.getElementById(Orig);
    var varToBox = document.getElementById(Dest);
    if ((varFromBox != null) && (varToBox != null))
    {
        if (varFromBox.length < 1)
        {
            alert('There are no items in the source ListBox');
            return false;
        }
        if (varFromBox.options.selectedIndex == -1) // when no Item is selected the index will be -1

        {
            alert('Please select an Item to move');
            return false;
        }
        while (varFromBox.options.selectedIndex >= 0)
        {
            var newOption = new Option(); // Create a new instance of ListItem

            newOption.text = varFromBox.options[varFromBox.options.selectedIndex].text;
            newOption.value = varFromBox.options[varFromBox.options.selectedIndex].value;
            varToBox.options[varToBox.length] = newOption; //Append the item in Target Listbox

            varFromBox.remove(varFromBox.options.selectedIndex); //Remove the item from Source Listbox

        }
    }
    return false;
}
function selectall() {
    selectBox = document.getElementById('sel');
    for (var i = 0; i < selectBox.options.length; i++) {
        selectBox.options[i].selected = true;
    }
}
function up() {
    obj = document.getElementById('sel');
    for (var i = 0; i < obj.options.length; i++)
        if (obj.options[ i ].selected) {
            if (i > 0)
                change(obj, i, i - 1);
        }

}

function down() {
    obj = document.getElementById('sel');
    for (var i = obj.options.length - 1; i >= 0; i--) {
        if (obj.options[ i ].selected) {
            if (i < obj.length - 1)
                change(obj, i, i + 1);
        }
    }
}
function change(obj, num1, num2) {
    proVal = obj.options[num1].value;
    proTex = obj.options[num1].text;
    obj.options[num1].value = obj.options[num2].value;
    obj.options[num1].text = obj.options[num2].text;
    obj.options[num2].value = proVal;
    obj.options[num2].text = proTex;
    obj.options[num2].selected = true;
    obj.options[num1].selected = false;
}

function required() {
    if ($("#profile").val() == "manual") {
        addAsterisk('matchtype[]');
    } else {
        deleteAsterisk('matchtype[]');
    }
    if ($("#srtp_mode").val() === "mandatory" || $("#srtp_mode").val() === "optional") {
        addAsterisk('srtp_crypto_suites[]');
    } else {
        deleteAsterisk('srtp_crypto_suites[]');
    }
    if ($("#sip_registrar").is(":blank") && !$("#enum_search_domains").is(":visible")) {
        addAsterisk('sip_proxy');
    } else {
        deleteAsterisk('sip_proxy');
    }
    if ($("#sip_proxy").is(":blank") && !$("#enum_search_domains").is(":visible")) {
        addAsterisk('sip_registrar');
    } else {
        deleteAsterisk('sip_registrar');
    }
}

==> appfs-24.01.02-rc05.tar.gz: usr/local/www/berogui/misc/script/sip.js <==
function hide_reg(value, state) {
    typeof state == 'undefined' ? state = true : state;
    if (value == false) {
        $('#reg').hide();
        $('#reg_option').hide();
        $('#regrefresh_on_validation_fail').hide(); 
    } else if (state === true) {
        if ($('input#validation').prop('checked')) { 
            $('#regrefresh_on_validation_fail').show(); 
        }
        $('#reg').show();
        $('#reg_option').show();
    }
}

function hide_validation(value, state) {
    typeof state == 'undefined' ? state = true : state;
    if (value == false) {
        $('#keepalive_int').hide();
        $('#regrefresh_on_validation_fail').hide();
    } else if (state === true) {
        $('#keepalive_int').show();
        if ($('input#register').prop('checked')) { 
            $('#regrefresh_on_validation_fail').show(); 
        }
    }
}


function dnsRegistration(mustShow) {
    if (mustShow == 1) {
        $('#dns_change_time').show();
        $('#dns_change_behavior').show();
    }
    else {
        $('#dns_change_time').hide();
        $('#dns_change_behavior').hide();
    }
}

function tlsSettings(mustShow) {
    if (mustShow == true) {
        $('#sips_on_tls_group').show();
    }
    else {
        $('#sips_on_tls_group').hide();
    }
}

function matchtype(manualSel) {
    if (manualSel == true) {
        $('select#matchtype>option:nth-child(1)').removeAttr('selected').prop('selected', false); //deselect address
        $('select#matchtype>option:nth-child(1)').prop('disabled', true);
        $('#matchtype_manual_group').show() //show manual
    } else {
        $('select#matchtype>option:nth-child(1)').prop('disabled', false);
        $('#matchtype_manual_group').hide()
    }
}


function hide_server(value) {
    if (value === false) {
        $('.sip_proxy').show();
        $('#sip_proxy').prop('disabled', false);
        $('.enum_search_domain').hide();
        $('#enum_search_domain').prop('disabled', true);
    } else if (value === true) {
        $('.sip_proxy').hide();
        $('#sip_proxy').prop('disabled', true);
        $('.enum_search_domain').show();
        $('#enum_search_domain').prop('disabled', false);
    }
}

function options(stun, externip, state) {
    typeof state == 'undefined' ? state = true : state;
    if ((stun == false && externip == false) || state == false) {
        $(".options").hide();
    } else if (state == true) {
        $(".options").show();
    }
    if (stun == true && state == true) {
        $(".stun").show();
        $(".externip").hide();
    } else {
        $(".stun").hide();
    }
    if (externip == true && state == true) {
        $(".externip").show();
        $(".stun").hide();
    } else {
        $(".externip").hide();
    }
}

function srtp() {
    if ($("#srtp_mode").val() == "off") {
        $("#srtp_crypto_suites").prop("disabled", true);
        $(".srtp_crypto_suites").hide();
        required();
    } else {
        $(".srtp_crypto_suites").show();
        $("#srtp_crypto_suites").prop("disabled", false);
        required();
    }
}
$("#stunradio").click(function () {
    $(".options").show();
    $(".stun").show();
    $(".externip").hide();
});
$("#externipradio").click(function () {
    $(".options").show();
    $(".externip").show();
    $(".stun").hide();
});
$("#nonatradio").click(function () {
    $(".options").hide();
    $(".externip").hide();
    $(".stun").hide();
});
$("#manual").click(function () {
    disable_ipMatchtype();
});


function move(Orig, Dest) {
    var varFromBox = document.getElementById(Orig);
    var varToBox = document.getElementById(Dest);
    if ((varFromBox != null) && (varToBox != null))
    {
        if (varFromBox.length < 1)
        {
            alert('There are no items in the source ListBox');
            return false;
        }
        if (varFromBox.options.selectedIndex == -1) // when no Item is selected the index will be -1

        {
            alert('Please select an Item to move');
            return false;
        }
        while (varFromBox.options.selectedIndex >= 0)
        {
            var newOption = new Option(); // Create a new instance of ListItem

            newOption.text = varFromBox.options[varFromBox.options.selectedIndex].text;
            newOption.value = varFromBox.options[varFromBox.options.selectedIndex].value;
            varToBox.options[varToBox.length] = newOption; //Append the item in Target Listbox

            varFromBox.remove(varFromBox.options.selectedIndex); //Remove the item from Source Listbox

        }
    }
    return false;
}
function selectall() {
    selectBox = document.getElementById('sel');
    for (var i = 0; i < selectBox.options.length; i++) {
        selectBox.options[i].selected = true;
    }
}
function up() {
    obj = document.getElementById('sel');
    for (var i = 0; i < obj.options.length; i++)
        if (obj.options[ i ].selected) {
            if (i > 0)
                change(obj, i, i - 1);
        }

}

function down() {
    obj = document.getElementById('sel');
    for (var i = obj.options.length - 1; i >= 0; i--) {
        if (obj.options[ i ].selected) {
            if (i < obj.length - 1)
                change(obj, i, i + 1);
        }
    }
}
function change(obj, num1, num2) {
    proVal = obj.options[num1].value;
    proTex = obj.options[num1].text;
    obj.options[num1].value = obj.options[num2].value;
    obj.options[num1].text = obj.options[num2].text;
    obj.options[num2].value = proVal;
    obj.options[num2].text = proTex;
    obj.options[num2].selected = true;
    obj.options[num1].selected = false;
}

function required() {
    if ($("#profile").val() == "manual") {
        addAsterisk('matchtype[]');
    } else {
        deleteAsterisk('matchtype[]');
    }
    if ($("#srtp_mode").val() === "mandatory" || $("#srtp_mode").val() === "optional") {
        addAsterisk('srtp_crypto_suites[]');
    } else {
        deleteAsterisk('srtp_crypto_suites[]');
    }
    if ($("#sip_registrar").is(":blank") && !$("#enum_search_domain").is(":visible")) {
        addAsterisk('sip_proxy');
    } else {
        deleteAsterisk('sip_proxy');
    }
    if ($("#sip_proxy").is(":blank") && !$("#enum_search_domain").is(":visible")) {
        addAsterisk('sip_registrar');
    } else {
        deleteAsterisk('sip_registrar');
    }
}
